"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isDefined = void 0;
const Predicate_1 = require("./Predicate");
/**
 * @desc Ensures that the `value` is defined as anything other than {@link null} or {@link undefined}.
 *
 * @example
 * import { ensure, isDefined, TinyType } from 'tiny-types';
 *
 * class Name extends TinyType {
 *     constructor(public readonly value: string) {
 *       ensure('Name', value, isDefined());
 *     }
 * }
 *
 * @returns {Predicate<T>}
 */
function isDefined() {
    return Predicate_1.Predicate.to(`be defined`, (value) => !(value === null || value === undefined));
}
exports.isDefined = isDefined;
//# sourceMappingURL=isDefined.js.map