"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGreaterThan = void 0;
const Predicate_1 = require("./Predicate");
/**
 * @desc Ensures that the `value` is greater than the `lowerBound`.
 *
 * @example
 * import { ensure, isGreaterThan, TinyType } from 'tiny-types';
 *
 * class AgeInYears extends TinyType {
 *     constructor(public readonly value: number) {
 *         ensure('Age in years', value, isGreaterThan(0));
 *     }
 * }
 *
 * @param {number} lowerBound
 * @returns {Predicate<number>}
 */
function isGreaterThan(lowerBound) {
    return Predicate_1.Predicate.to(`be greater than ${lowerBound}`, (value) => typeof value === 'number' &&
        Number.isFinite(value) &&
        lowerBound < value);
}
exports.isGreaterThan = isGreaterThan;
//# sourceMappingURL=isGreaterThan.js.map