"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isGreaterThanOrEqualTo = void 0;
const isEqualTo_1 = require("./isEqualTo");
const isGreaterThan_1 = require("./isGreaterThan");
const or_1 = require("./or");
/**
 * @desc Ensures that the `value` is greater than or equal to the `lowerBound`.
 *
 * @example
 * import { ensure, isGreaterThanOrEqualTo, TinyType } from 'tiny-types';
 *
 * class AgeInYears extends TinyType {
 *     constructor(public readonly value: number) {
 *         ensure('Age in years', value, isGreaterThanOrEqualTo(18));
 *     }
 * }
 *
 * @param {number} lowerBound
 * @returns {Predicate<number>}
 */
function isGreaterThanOrEqualTo(lowerBound) {
    return (0, or_1.or)((0, isEqualTo_1.isEqualTo)(lowerBound), (0, isGreaterThan_1.isGreaterThan)(lowerBound));
}
exports.isGreaterThanOrEqualTo = isGreaterThanOrEqualTo;
//# sourceMappingURL=isGreaterThanOrEqualTo.js.map