"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isInteger = void 0;
const Predicate_1 = require("./Predicate");
/**
 * @desc Ensures that the `value` is an integer {@link Number}.
 *
 * @example
 * import { ensure, isInteger, TinyType } from 'tiny-types';
 *
 * class AgeInYears extends TinyType {
 *     constructor(public readonly value: number) {
 *         ensure('Age in years', value, isInteger());
 *     }
 * }
 *
 * @returns {Predicate<number>}
 */
function isInteger() {
    return Predicate_1.Predicate.to(`be an integer`, (value) => typeof value === 'number' &&
        Number.isFinite(value) &&
        Math.floor(value) === value);
}
exports.isInteger = isInteger;
//# sourceMappingURL=isInteger.js.map