"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isLessThan = void 0;
const Predicate_1 = require("./Predicate");
/**
 * @desc Ensures that the `value` is less than the `upperBound`.
 *
 * @example
 * import { ensure, isLessThan, TinyType } from 'tiny-types';
 *
 * class InvestmentPeriodInYears extends TinyType {
 *     constructor(public readonly value: number) {
 *         ensure('Investment period in years', value, isLessThan(50));
 *     }
 * }
 *
 * @param {number} upperBound
 * @returns {Predicate<number>}
 */
function isLessThan(upperBound) {
    return Predicate_1.Predicate.to(`be less than ${upperBound}`, (value) => typeof value === 'number' &&
        Number.isFinite(value) &&
        value < upperBound);
}
exports.isLessThan = isLessThan;
//# sourceMappingURL=isLessThan.js.map