"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isLessThanOrEqualTo = void 0;
const isEqualTo_1 = require("./isEqualTo");
const isLessThan_1 = require("./isLessThan");
const or_1 = require("./or");
/**
 * @desc Ensures that the `value` is less than or equal to the `upperBound`.
 *
 * @example
 * import { ensure, isLessThanOrEqualTo, TinyType } from 'tiny-types';
 *
 * class InvestmentPeriod extends TinyType {
 *     constructor(public readonly value: number) {
 *         ensure('InvestmentPeriod', value, isLessThanOrEqualTo(50));
 *     }
 * }
 *
 * @param {number} upperBound
 * @returns {Predicate<number>}
 */
function isLessThanOrEqualTo(upperBound) {
    return (0, or_1.or)((0, isLessThan_1.isLessThan)(upperBound), (0, isEqualTo_1.isEqualTo)(upperBound));
}
exports.isLessThanOrEqualTo = isLessThanOrEqualTo;
//# sourceMappingURL=isLessThanOrEqualTo.js.map