"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isNumber = void 0;
const Predicate_1 = require("./Predicate");
/**
 * @desc Ensures that the `value` is a {@link Number}.
 *
 * @example
 * import { ensure, isNumber, TinyType } from 'tiny-types';
 *
 * class Percentage extends TinyType {
 *     constructor(public readonly value: number) {
 *         ensure('Percentage', value, isNumber());
 *     }
 * }
 *
 * @returns {Predicate<number>}
 */
function isNumber() {
    return Predicate_1.Predicate.to(`be a number`, (value) => typeof value === 'number');
}
exports.isNumber = isNumber;
//# sourceMappingURL=isNumber.js.map